<?php
/**
 * @package   AdminTools
 * @copyright 2010-2021 Akeeba Ltd / Nicholas K. Dionysopoulos
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\AdminTools\Administrator\Controller\Mixin;


use Akeeba\Component\AdminTools\Administrator\Table\TempsuperuserTable;
use Joomla\CMS\Language\Text;
use RuntimeException;

defined('_JEXEC') or die;

trait TempSuperUserChecks
{
	/**
	 * Asserts that I am not trying to modify my own user.
	 *
	 * If you do not specify the user ID being edited / created we'll figure it out from the request using the model.
	 *
	 * @param   int|null  $editingID  The ID of the user being edited.
	 *
	 * @since   5.3.0
	 */
	protected function assertNotMyself(?int $editingID)
	{
		if (empty($editingID))
		{
			return;
		}

		if ($editingID == $this->app->getIdentity()->id)
		{
			throw new RuntimeException(Text::sprintf('COM_ADMINTOOLS_TEMPSUPERUSERS_ERR_CANTEDITSELF'), 403);
		}

	}

	/**
	 * Asserts that I am not a temporary Super User myself
	 *
	 * @since   5.3.0
	 */
	protected function assertNotTemporary()
	{
		/** @var TempsuperuserTable $table */
		$table = $this->getModel('Tempsuperuser', 'Administrator')->getTable();

		if ($table->load($this->app->getIdentity()->id))
		{
			throw new RuntimeException(Text::sprintf('COM_ADMINTOOLS_TEMPSUPERUSERS_ERR_UNAVAILABLETOTEMP'), 403);
		}
	}
}